==> huaweicloudsdkdds-3.0.54-py2.py3-none-any.whl: huaweicloudsdkdds/v3/model/attach_eip_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AttachEipRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'node_id': 'str',
        'body': 'AttachEipRequestBody'
    }

    attribute_map = {
        'node_id': 'node_id',
        'body': 'body'
    }

    def __init__(self, node_id=None, body=None):
        """AttachEipRequest - a model defined in huaweicloud sdk"""
        
        

        self._node_id = None
        self._body = None
        self.discriminator = None

        self.node_id = node_id
        if body is not None:
            self.body = body

    @property
    def node_id(self):
        """Gets the node_id of this AttachEipRequest.

        需要绑定公网IP的节点ID。集群实例选择mongos节点，副本集实例选择primary或者secondary节点，单节点实例选择primary节点。

        :return: The node_id of this AttachEipRequest.
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this AttachEipRequest.

        需要绑定公网IP的节点ID。集群实例选择mongos节点，副本集实例选择primary或者secondary节点，单节点实例选择primary节点。

        :param node_id: The node_id of this AttachEipRequest.
        :type: str
        """
        self._node_id = node_id

    @property
    def body(self):
        """Gets the body of this AttachEipRequest.


        :return: The body of this AttachEipRequest.
        :rtype: AttachEipRequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this AttachEipRequest.


        :param body: The body of this AttachEipRequest.
        :type: AttachEipRequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachEipRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdds-3.0.66-py2.py3-none-any.whl: huaweicloudsdkdds/v3/model/attach_eip_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AttachEipRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'node_id': 'str',
        'body': 'AttachEipRequestBody'
    }

    attribute_map = {
        'node_id': 'node_id',
        'body': 'body'
    }

    def __init__(self, node_id=None, body=None):
        """AttachEipRequest - a model defined in huaweicloud sdk"""
        
        

        self._node_id = None
        self._body = None
        self.discriminator = None

        self.node_id = node_id
        if body is not None:
            self.body = body

    @property
    def node_id(self):
        """Gets the node_id of this AttachEipRequest.

        需要绑定公网IP的节点ID。集群实例选择mongos节点，副本集实例选择primary或者secondary节点，单节点实例选择primary节点。

        :return: The node_id of this AttachEipRequest.
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this AttachEipRequest.

        需要绑定公网IP的节点ID。集群实例选择mongos节点，副本集实例选择primary或者secondary节点，单节点实例选择primary节点。

        :param node_id: The node_id of this AttachEipRequest.
        :type: str
        """
        self._node_id = node_id

    @property
    def body(self):
        """Gets the body of this AttachEipRequest.


        :return: The body of this AttachEipRequest.
        :rtype: AttachEipRequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this AttachEipRequest.


        :param body: The body of this AttachEipRequest.
        :type: AttachEipRequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachEipRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
